import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import ReactDropdown from 'react-dropdown';
import { csv, arc, pie, scaleBand, scaleLinear, max, format } from 'd3';
import { Dropdown } from './Dropdown';


const menuHeight = 80;
const width = 960;
const height = 500 - menuHeight;

const margin = { top: 20 , right: 20, bottom: 35, left: 50 };
const bottomlabeloffset =85;
const columnlabeloffset =35;
const options = [
  { value: 'all', label: 'All' },
  { value: 'city', label: 'City' },
  { value: 'rural', label: 'Rural' },
  { value: 'suburb', label: 'Suburb' }
];
const initialValue = 'all';

const csvUrl =
  'https://gist.githubusercontent.com/wenleicao/24da06aff2538ba8740e559c7e670257/raw/0848a467203d57738a0aec5d069ed2f7b23f2d1a/city_crime_population_ratio.csv';

const App = () => {
  let [data, setData] = useState(null);
  let [selectedValue, setSelectedValue] = useState(initialValue);
  console.log(selectedValue);
  
  useEffect(() => {
    const row = d => {
      d.Crime_Ratio = +d['crime_rate'];
      return d;
    };
        
    
    
    csv(csvUrl, row).then(
     
      //console.log(window.selectedValue);
      //setData(data.filter(d => d.communtiy === "rural").slice(0, 10));
      setData
     
      
    );
  }, []);

  
 
  if (!data) {
    return <pre>Loading...</pre>;
  }
 //console.log(data[0]);
 // const filteredData=data.filter(d => d.communtiy ===selectedValue).slice(0, 10);
  const filteredData=data.filter(d =>(selectedValue ==="all"? d : d.communtiy ===selectedValue)).slice(0, 10);
  console.log(selectedValue);
  console.log(filteredData)
 // console.log(data.length);
  
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleLinear()
    .domain([0, max(filteredData, d => d.Crime_Ratio)])
    .range([innerHeight, 0]);   //original [0, innerHeight], need to show bigger number up

  const xScale = scaleBand()
    .domain(filteredData.map(d => d.City))
    .range([0, innerWidth])
  	.padding (0.2) ;
 //console.log(yScale.ticks());
  return (
    <>
     <div className="menus-container">
      <span className="dropdown-label">Choose a community:</span>
       <ReactDropdown 
        options={options}
        id="Community-select"
        value={selectedValue}
       onChange={({ value }) => setSelectedValue(value)}
      />
     </div>

    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${-margin.bottom})`}>
//axisleft
        {yScale.ticks().map(tickValue => (
          <g className = "tick" key={tickValue} transform={`translate(0, ${yScale(tickValue)} )`}>
            <line  x2={innerWidth} />
            <text style={{ textAnchor: 'end' }} x={-3} dy=".32em">
              {format(",.1%")	(tickValue)}
            </text>
          </g>
        ))}
//axisbottom 
      {xScale.domain().map(tickValue => (
          <g className = "tick">
          <text
            key={tickValue}
            style={{ textAnchor: 'middle'  } }
           // attr ={{transform:'rotate(-65)'}}
            dy=".71em"
            y={innerHeight + margin.top + columnlabeloffset
              }
            x={xScale(tickValue) + xScale.bandwidth() / 2}
          >
            {tickValue }
          </text>
          </g>
        ))}
//marks
        <g className = "mark">
        {filteredData.map(d => (
          <rect
            x={xScale(d.City)} //add margin left to leave space for y axis
            y={yScale(d.Crime_Ratio)
               
              } //minus the bottom so that it can leave room for x axis
            width={xScale.bandwidth()}
            height={height - yScale(d.Crime_Ratio)}
             >
             <title>{format(",.1%")(d.Crime_Ratio)}</title> 
              </rect>
        ))}          
          </g>
        <g className = "bottomlabel"> 
        <text x={innerWidth/2} y={innerHeight + bottomlabeloffset} textAnchor="middle" > Massachusetts Cities </text>
					</g>      
        </g>
    </svg>
      </>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
